@@ -1,7 +1,8 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
- *  Copyright (C) 2003-2004 Marco Pesenti Gritti
- *  Copyright (C) 2004, 2005 Christian Persch
+ *  Copyright © 2002 Jorn Baayen <jorn@nl.linux.org>
+ *  Copyright © 2003-2004 Marco Pesenti Gritti
+ *  Copyright © 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-favicon-cache.c,v 1.58 2006/06/01 19:35:31 jframeau Exp $
+ *  $Id: ephy-favicon-cache.c 6786 2007-01-03 08:18:47Z diegoe $
  */
 
 #include "config.h"
@@ -35,6 +36,7 @@
 #include "ephy-node-common.h"
 #include "ephy-node.h"
 #include "ephy-debug.h"
+#include "ephy-glib-compat.h"
 
 #include <glib/gstdio.h>
 #include <libgnomeui/libgnomeui.h>
@@ -45,12 +47,13 @@
 #define EPHY_FAVICON_CACHE_XML_VERSION (const xmlChar *)"1.1"
 
 #define EPHY_FAVICON_CACHE_OBSOLETE_DAYS 30
+#define SECS_PER_DAY (60*60*24)
 
-/* how often to save the cache, in milliseconds */
-#define CACHE_SAVE_INTERVAL	10 * 60 * 1000 /* ms */
+/* how often to save the cache, in seconds */
+#define CACHE_SAVE_INTERVAL	(10 * 60) /* seconds */
 
-/* how often to delete old pixbufs from the cache, in milliseconds */
-#define CACHE_CLEANUP_INTERVAL	5 * 60 * 1000 /* ms */
+/* how often to delete old pixbufs from the cache, in seconds */
+#define CACHE_CLEANUP_INTERVAL	(5 * 60) /* seconds */
 
 /* how long to keep pixbufs in cache, in seconds. This should be longer than CACHE_CLEANUP_INTERVAL */
 #define PIXBUF_CACHE_KEEP_TIME	10 * 60 /* s */
@@ -88,7 +91,7 @@ typedef struct
 	guint load_failed : 1;
 } PixbufCacheEntry;
 
-typedef gboolean (* FilterFunc) (EphyNode*, GDate *);
+typedef gboolean (* FilterFunc) (EphyNode*, time_t);
 
 enum
 {
@@ -125,7 +128,7 @@ ephy_favicon_cache_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyFaviconCacheClass),
 			NULL,
@@ -187,23 +190,13 @@ pixbuf_cache_entry_free (PixbufCacheEntry *entry)
 }
 
 static gboolean
-icon_is_obsolete (EphyNode *node, GDate *now)
+icon_is_obsolete (EphyNode *node, time_t now)
 {
 	int last_visit;
-	GDate date;
 
 	last_visit = ephy_node_get_property_int
 		(node, EPHY_NODE_FAVICON_PROP_LAST_USED);
-
-	g_date_clear (&date, 1);
-#if GLIB_CHECK_VERSION (2,9,0)
-        g_date_set_time_t (&date, last_visit);
-#else
-	g_date_set_time (&date, last_visit);
-#endif
-
-	return (g_date_days_between (&date, now) >=
-		EPHY_FAVICON_CACHE_OBSOLETE_DAYS);
+	return now - last_visit >= EPHY_FAVICON_CACHE_OBSOLETE_DAYS*SECS_PER_DAY;
 }
 
 static void
@@ -237,14 +230,9 @@ remove_obsolete_icons (EphyFaviconCache *cache,
 	EphyFaviconCachePrivate *priv = cache->priv;
 	GPtrArray *children;
 	int i;
-	GDate current_date;
+	time_t now;
 
-	g_date_clear (&current_date, 1);
-#if GLIB_CHECK_VERSION (2,9,0)
-        g_date_set_time_t (&current_date, time (NULL));
-#else
-	g_date_set_time (&current_date, time (NULL));
-#endif
+	now = time (NULL);
 
 	children = ephy_node_get_children (priv->icons);
 	for (i = (int) children->len - 1; i >= 0; i--)
@@ -253,7 +241,7 @@ remove_obsolete_icons (EphyFaviconCache *cache,
 
 		kid = g_ptr_array_index (children, i);
 
-		if (!filter || filter (kid, &current_date))
+		if (!filter || filter (kid, now))
 		{
 			const char *filename;
 			char *path;
@@ -394,10 +382,10 @@ ephy_favicon_cache_init (EphyFaviconCache *cache)
 	g_signal_connect_object (embed_shell, "prepare-close",
 				 G_CALLBACK (prepare_close_cb), cache, 0);
 
-	priv->autosave_timeout = g_timeout_add (CACHE_SAVE_INTERVAL,
+	priv->autosave_timeout = g_timeout_add_seconds (CACHE_SAVE_INTERVAL,
 						(GSourceFunc) periodic_save_cb,
 						cache);
-	priv->cleanup_timeout = g_timeout_add (CACHE_CLEANUP_INTERVAL,
+	priv->cleanup_timeout = g_timeout_add_seconds (CACHE_CLEANUP_INTERVAL,
 					       (GSourceFunc) periodic_cleanup_cb,
 					       cache);
 }
@@ -590,11 +578,11 @@ ephy_favicon_cache_get (EphyFaviconCache *cache,
 	time_t now;
 	PixbufCacheEntry *entry;
 	EphyNode *icon;
-	GValue value = { 0, };
 	char *pix_file;
 	GdkPixbuf *pixbuf = NULL;
 	guint checklevel = NEEDS_MASK;
 	int width, height;
+	int favicon_checked;
 
 	if (url == NULL) return NULL;
 
@@ -629,23 +617,15 @@ ephy_favicon_cache_get (EphyFaviconCache *cache,
 		filename = gnome_thumbnail_md5 (url);
 
 		icon = ephy_node_new (cache->priv->db);
-		g_value_init (&value, G_TYPE_STRING);
-		g_value_set_string (&value, url);
-		ephy_node_set_property (icon, EPHY_NODE_FAVICON_PROP_URL,
-					&value);
-		g_value_unset (&value);
-
-		g_value_init (&value, G_TYPE_STRING);
-		g_value_set_string (&value, filename);
-		ephy_node_set_property (icon, EPHY_NODE_FAVICON_PROP_FILENAME,
-					&value);
-		g_value_unset (&value);
-
-		g_value_init (&value, G_TYPE_INT);
-		g_value_set_int (&value, (int) NEEDS_MASK & ~NEEDS_RENAME);
-		ephy_node_set_property (icon, EPHY_NODE_FAVICON_PROP_CHECKED,
-					&value);
-		g_value_unset (&value);
+		ephy_node_set_property_string (icon,
+					       EPHY_NODE_FAVICON_PROP_URL,
+					       url);
+		ephy_node_set_property_string (icon,
+					       EPHY_NODE_FAVICON_PROP_FILENAME,
+					       filename);
+		ephy_node_set_property_int (icon,
+					    EPHY_NODE_FAVICON_PROP_CHECKED,
+					    (int) NEEDS_MASK & ~NEEDS_RENAME);
 
 		/* This will also add an entry to the icons hash */
 		ephy_node_add_child (priv->icons, icon);
@@ -663,11 +643,8 @@ ephy_favicon_cache_get (EphyFaviconCache *cache,
 	icon = entry->node;
 
 	/* update timestamp */
-	g_value_init (&value, G_TYPE_INT);
-	g_value_set_int (&value, now);
-	ephy_node_set_property (icon, EPHY_NODE_FAVICON_PROP_LAST_USED,
-				&value);
-	g_value_unset (&value);
+	ephy_node_set_property_int (icon, EPHY_NODE_FAVICON_PROP_LAST_USED,
+				    now);
 
 	priv->dirty = TRUE;
 
@@ -690,17 +667,18 @@ ephy_favicon_cache_get (EphyFaviconCache *cache,
 	}
 
 	/* Check for supported icon types */
-	if (ephy_node_get_property (icon, EPHY_NODE_FAVICON_PROP_CHECKED, &value) &&
-	    G_VALUE_HOLDS (&value, G_TYPE_INT))
+	favicon_checked = ephy_node_get_property_int
+		(icon, EPHY_NODE_FAVICON_PROP_CHECKED);
+	if (favicon_checked != -1)
 	{
-		checklevel = (guint) g_value_get_int (&value);
-		g_value_unset (&value);
+		checklevel = (guint) favicon_checked;
 	}
 
 	/* First, update the filename */
 	if (checklevel & NEEDS_RENAME)
 	{
 		char *new_pix_file, *urlhash;
+		GValue value = { 0, };
 
 		urlhash = gnome_thumbnail_md5 (url);
 		new_pix_file = g_build_filename (cache->priv->directory, urlhash, NULL);
@@ -717,10 +695,9 @@ ephy_favicon_cache_get (EphyFaviconCache *cache,
 		pix_file = new_pix_file;
 
 		checklevel &= ~NEEDS_RENAME;
-		g_value_init (&value, G_TYPE_INT);
-		g_value_set_int (&value, (int) checklevel);
-		ephy_node_set_property (icon, EPHY_NODE_FAVICON_PROP_CHECKED, &value);
-		g_value_unset (&value);
+		ephy_node_set_property_int (icon,
+					    EPHY_NODE_FAVICON_PROP_CHECKED,
+					    (int) checklevel);
 	}
 
 	/* Now check the type. We renamed the file above, so gnome-vfs does NOT
@@ -790,16 +767,13 @@ ephy_favicon_cache_get (EphyFaviconCache *cache,
 			/* gnome_vfs_unlink (pix_file); */
 		}
 
-		g_value_init (&value, G_TYPE_INT);
-		g_value_set_int (&value, (int) checklevel);
-		ephy_node_set_property (icon, EPHY_NODE_FAVICON_PROP_CHECKED, &value);
-		g_value_unset (&value);
+		ephy_node_set_property_int (icon,
+					    EPHY_NODE_FAVICON_PROP_CHECKED,
+					    (int) checklevel);
 
 		/* epiphany 1.6 compat */
-		g_value_init (&value, G_TYPE_BOOLEAN);
-		g_value_set_boolean (&value, valid);
-		ephy_node_set_property (icon, EPHY_NODE_FAVICON_PROP_CHECKOLD, &value);
-		g_value_unset (&value);
+		ephy_node_set_property_boolean
+			(icon, EPHY_NODE_FAVICON_PROP_CHECKOLD, valid);
 	}
 
 	/* if it still needs the check, mime type couldn't be checked. Deny! */
