@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.h,v 1.53.2.1 2006/09/13 11:48:35 chpe Exp $
+ *  $Id: EphyBrowser.h 6655 2006-10-22 17:08:06Z jframeau $
  */
 
 #ifndef EPHY_BROWSER_H
@@ -36,6 +36,7 @@
 #include <nsIWebBrowserFocus.h>
 #include <nsIWebBrowser.h>
 #include <nsIWebNavigation.h>
+#include <nsPIDOMWindow.h>
 
 #ifdef ALLOW_PRIVATE_API
 #include <nsIContentViewer.h>
@@ -172,6 +173,7 @@ public:
 	nsresult GetDocumentURI (nsIURI **aURI);
 	nsresult GetTargetDocumentURI (nsIURI **aURI);
 	nsresult GetDOMWindow (nsIDOMWindow **window);
+	nsresult GetPIDOMWindow(nsPIDOMWindow **aPIWin);
 
 	nsresult GetHasModifiedForms (PRBool *modified);
 
@@ -183,6 +185,10 @@ public:
 
 	nsresult Close ();
 
+	nsresult LoadURI(const char *aURI, 
+			 PRUint32 aLoadFlags = nsIWebNavigation::LOAD_FLAGS_NONE, 
+			 nsIURI *aURI = nsnull);
+
         EphyEmbedDocumentType GetDocumentType ();
 
 	nsCOMPtr<nsIWebBrowser> mWebBrowser;
