@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* 
  *  Copyright © 2002 Jorn Baayen <jorn@nl.linux.org>
  *
@@ -15,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-view.c,v 1.66.2.2 2006/09/13 11:48:49 chpe Exp $
+ *  $Id: ephy-node-view.c 6796 2007-01-08 22:53:47Z diegoe $
  */
 
 #include "config.h"
@@ -159,16 +160,21 @@ static EphyNode *
 get_node_from_path (EphyNodeView *view, GtkTreePath *path)
 {
 	EphyNode *node;
-	GtkTreeIter iter, iter2;
+	GtkTreeIter iter, iter2, iter3;
 
 	if (path == NULL) return NULL;
 
 	gtk_tree_model_get_iter (view->priv->sortmodel, &iter, path);
 	gtk_tree_model_sort_convert_iter_to_child_iter
 		(GTK_TREE_MODEL_SORT (view->priv->sortmodel), &iter2, &iter);
+
+	if (iter2.stamp == 0) {
+		return NULL;
+	}
 	gtk_tree_model_filter_convert_iter_to_child_iter
-		(GTK_TREE_MODEL_FILTER (view->priv->filtermodel), &iter, &iter2);
-	node = ephy_tree_model_node_node_from_iter (view->priv->nodemodel, &iter);
+		(GTK_TREE_MODEL_FILTER (view->priv->filtermodel), &iter3, &iter2);
+
+	node = ephy_tree_model_node_node_from_iter (view->priv->nodemodel, &iter3);
 
 	return node;
 }
@@ -959,7 +965,6 @@ cell_renderer_edited (GtkCellRendererText *cell,
                       const char *new_text,
                       EphyNodeView *view)
 {
-	GValue value = { 0, };
 	GtkTreePath *path;
 	GtkTreeIter iter, iter2;
 	EphyNode *node;
@@ -978,12 +983,8 @@ cell_renderer_edited (GtkCellRendererText *cell,
 		(GTK_TREE_MODEL_FILTER (view->priv->filtermodel), &iter, &iter2);
 	node = ephy_tree_model_node_node_from_iter (view->priv->nodemodel, &iter);
 
-	g_value_init (&value, G_TYPE_STRING);
-	g_value_set_string (&value, new_text);
-	ephy_node_set_property (node,
-			        view->priv->editable_property,
-			        &value);
-	g_value_unset (&value);
+	ephy_node_set_property_string (node, view->priv->editable_property,
+				       new_text);
 
 	gtk_tree_path_free (path);
 
@@ -1377,7 +1378,7 @@ ephy_node_view_remove (EphyNodeView *view)
 	EphyNodeViewPrivate *priv = view->priv;
 	GList *list, *l;
 	EphyNode *node;
-	GtkTreeIter iter, iter2;
+	GtkTreeIter iter, iter2, iter3;
 	GtkTreePath *path;
 	GtkTreeRowReference *row_ref = NULL;
 	GtkTreeSelection *selection;
@@ -1392,9 +1393,9 @@ ephy_node_view_remove (EphyNodeView *view)
 
 	node = g_list_first (list)->data;
 	ephy_tree_model_node_iter_from_node (EPHY_TREE_MODEL_NODE (view->priv->nodemodel),
-					     node, &iter);
+					     node, &iter3);
 	gtk_tree_model_filter_convert_child_iter_to_iter (GTK_TREE_MODEL_FILTER (view->priv->filtermodel),
-							  &iter2, &iter);
+							  &iter2, &iter3);
 	gtk_tree_model_sort_convert_child_iter_to_iter (GTK_TREE_MODEL_SORT (view->priv->sortmodel),
 							&iter, &iter2);
 	iter2 = iter;
