@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmark-action.c 6588 2006-09-13 11:34:25Z chpe $
+ *  $Id: ephy-bookmark-action.c 6830 2007-01-18 12:36:08Z lferrett $
  */
 
 #include "config.h"
@@ -214,7 +214,7 @@ ephy_bookmark_action_sync_icon (GtkAction *action,
 
 		if (pixbuf == NULL && icon_location == NULL)
 		{
-			pixbuf = gtk_widget_render_icon (proxy, STOCK_BOOKMARK,
+			pixbuf = gtk_widget_render_icon (proxy, EPHY_STOCK_BOOKMARK,
 							 GTK_ICON_SIZE_MENU, NULL);
 		}
 
