@@ -1,6 +1,6 @@
 /* 
- *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003-2005 Christian Persch
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2003-2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-fullscreen-popup.c,v 1.7 2005/10/20 13:12:56 chpe Exp $
+ *  $Id: ephy-fullscreen-popup.c 6588 2006-09-13 11:34:25Z chpe $
  */
 
 #include "config.h"
@@ -239,8 +239,7 @@ ephy_fullscreen_popup_constructor (GType type,
 	gtk_window_set_resizable (window, FALSE);
 
 	priv->tooltips = gtk_tooltips_new ();
-	g_object_ref (G_OBJECT (priv->tooltips));
-	gtk_object_sink (GTK_OBJECT (priv->tooltips));
+	g_object_ref_sink (priv->tooltips);
 
 	hbox = gtk_hbox_new (FALSE, 2);
 	gtk_container_add (GTK_CONTAINER (window), hbox);
@@ -422,7 +421,7 @@ ephy_fullscreen_popup_class_init (EphyFullscreenPopupClass *klass)
 							      "Window",
 							      "Parent window",
 							      EPHY_TYPE_WINDOW,
-							      G_PARAM_WRITABLE |
+							      G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 							      G_PARAM_CONSTRUCT_ONLY));
 
 	g_type_class_add_private (object_class, sizeof (EphyFullscreenPopupPrivate));
@@ -435,7 +434,7 @@ ephy_fullscreen_popup_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyFullscreenPopupClass),
 			NULL,
