@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-main.c 6775 2006-12-31 17:00:43Z chpe $
+ *  $Id: ephy-main.c 6810 2007-01-09 00:40:44Z diegoe $
  */
 
 #include "config.h"
@@ -91,7 +91,7 @@ static const GOptionEntry option_entries[] =
 	{ "profile", 0, 0, G_OPTION_ARG_STRING, &profile_directory,
 	  N_("Profile directory to use in the private instance"), N_("DIR") },
 	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &arguments,
-	  "", N_("URL ...")},
+	  "", N_("URL …")},
 	{ NULL }
 };
 
