@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.h,v 1.23 2005/12/11 14:40:15 chpe Exp $
+ *  $Id: window-commands.h 6605 2006-09-24 19:59:37Z jframeau $
  */
 
 #include <gtk/gtkaction.h>
@@ -43,12 +43,6 @@ void window_cmd_view_reload	(GtkAction *action,
 void window_cmd_new		(GtkAction *action,
 				 EphyWindow *window);
 
-void window_cmd_file_new_window	(GtkAction *action,
-				 EphyWindow *window);
-
-void window_cmd_file_new_tab	(GtkAction *action,
-				 EphyWindow *window);
-
 void window_cmd_file_bookmark_page(GtkAction *action,
 				  EphyWindow *window);
 
@@ -94,6 +88,9 @@ void window_cmd_edit_copy	(GtkAction *action,
 void window_cmd_edit_paste	(GtkAction *action,
 				 EphyWindow *window);
 
+void window_cmd_edit_delete	(GtkAction *action,
+				 EphyWindow *window);
+
 void window_cmd_edit_select_all (GtkAction *action,
 				 EphyWindow *window);
 
@@ -118,6 +115,9 @@ void window_cmd_view_zoom_normal(GtkAction *action,
 void window_cmd_view_page_source(GtkAction *action,
 				 EphyWindow *window);
 
+void window_cmd_view_page_security_info (GtkAction *action,
+					 EphyWindow *window);
+
 void window_cmd_go_history	(GtkAction *action,
 				 EphyWindow *window);
 
